@@ -23,7 +23,6 @@ import re
 import string
 import time
 import warnings
-import logging
 from collections import deque, OrderedDict
 
 import requests
@@ -33,7 +32,7 @@ from threading import Barrier, Condition, Thread
 
 from .multipart import Data
 
-__version__ = "0.9.5"
+__version__ = "0.9.6"
 
 BASE_URL = "https://volafile.io"
 BASE_ROOM_URL = BASE_URL + "/r/"
@@ -41,19 +40,6 @@ BASE_REST_URL = BASE_URL + "/rest/"
 BASE_WS_URL = "wss://volafile.io/api/"
 
 
-def random_id(length):
-    """Generates a random ID of n length"""
-    def char():
-        """Generate single random char"""
-        return random.choice(string.ascii_letters + string.digits)
-    return ''.join(char() for _ in range(length))
-
-
-def to_json(obj):
-    """Create a compact JSON string from an object"""
-    return json.dumps(obj, separators=(',', ':'))
-
-
 def parse_chat_message(data):
     """Parses the data for a json chat message and returns a
     ChatMessage object"""
@@ -92,6 +78,19 @@ def parse_chat_message(data):
     return chat_message
 
 
+def random_id(length):
+    """Generates a random ID of n length"""
+    def char():
+        """Generate single random char"""
+        return random.choice(string.ascii_letters + string.digits)
+    return ''.join(char() for _ in range(length))
+
+
+def to_json(obj):
+    """Create a compact JSON string from an object"""
+    return json.dumps(obj, separators=(',', ':'))
+
+
 class Connection(requests.Session):
 
     """Bundles a requests/websocket pair"""
@@ -250,9 +249,6 @@ class RoomConnection(Connection):
                             room.add_data(json_data)
                             with self.condition:
                                 self.condition.notify_all()
-
-            except:
-                logging.exception('')
             finally:
                 try:
                     self.close()
@@ -287,8 +283,9 @@ class Room:
             r.post_chat("Hello, world!")
             r.upload_file("onii-chan.ogg")
     """
+    # pylint: disable=too-many-instance-attributes
 
-    def __init__(self, name=None, user=None):
+    def __init__(self, name=None, user=None, subscribe=True):
         """name is the room name, if none then makes a new room
         user is your user name, if none then generates one for you"""
 
@@ -307,7 +304,7 @@ class Room:
         self._config = {}
         try:
             if not room_resp:
-                room_resp = self.conn.get(BASE_URL + "/" + self.name)
+                room_resp = self.conn.get(BASE_ROOM_URL + self.name)
             text = room_resp.text
             text = text.replace('\n', '')
             text = re.sub(r'(\w+):', r'"\1":', text)
@@ -330,16 +327,18 @@ class Room:
         except Exception:
             raise IOError("Failed to get room config")
 
+        if not subscribe and not user:
+            user = random_id(6)
         self.user = User(user, self.conn, max_nick)
-        self.owner = False
-
-        self.conn.subscribe(self.name, self.user.name, secret_key)
+        self.owner = bool(secret_key)
 
         self._user_count = 0
         self._files = OrderedDict()
         self._chat_log = []
 
-        self.conn.listen_forever(self)
+        if subscribe:
+            self.conn.subscribe(self.name, self.user.name, secret_key)
+            self.conn.listen_forever(self)
 
     def __repr__(self):
         return ("<Room({},{},connected={})>".
@@ -387,10 +386,12 @@ class Room:
                 files = data['files']
                 for file in files:
                     self.conn.enqueue_file(file[0])
-                    self._files[file[0]] = File(file[0],
-                                                file[1],
-                                                file[2],
-                                                file[3],
+                    self._files[file[0]] = File(file[0],  # id
+                                                file[1],  # name
+                                                file[2],  # type
+                                                file[3],  # size
+                                                # file[4],  # upload time
+                                                # file[5],  # expire time
                                                 file[6]['user'])
             elif data_type == "delete_file":
                 del self._files[data]
@@ -402,6 +403,8 @@ class Room:
                 change = data
                 if change['key'] == 'name':
                     self._config['title'] = change['value']
+                if change['key'] == 'file_ttl':
+                    self._config['ttl'] = change['value']
                 elif change['key'] == 'private':
                     self._config['private'] = change['value'] == 'true'
                 elif change['key'] == 'motd':
@@ -415,7 +418,13 @@ class Room:
                 self.user.name = data
             elif data_type == "owner":
                 self.owner = True
-            elif data_type in ("time", "subscribed"):
+            elif data_type == "time":
+                # TODO
+                pass
+            elif data_type == "update_assets":
+                # TODO
+                pass
+            elif data_type in ("subscribed", "hooks"):
                 pass
             else:
                 warnings.warn(
@@ -475,6 +484,10 @@ class Room:
         You may specify upload_as to change the name it is uploaded as.
         You can also specify a blocksize and a callback if you wish.
         Returns the file's id on success and None on failure."""
+        if os.stat(filename).st_size > self._config['max_file']:
+            raise ValueError(
+                "File must be at most {} GB".format(
+                    self._config['max_file'] >> 30))
         file = filename if hasattr(filename, "read") else open(filename, 'rb')
         filename = upload_as or os.path.split(filename)[1]
 
@@ -598,7 +611,8 @@ class File:
             name,
             file_type=None,
             size=None,
-            uploader=None):
+            uploader=None
+    ):
         self.file_id = file_id
         self.name = name
         self.file_type = file_type
